Class: Google::Api::GoSettings
- Inherits:
-
Object
- Object
- Google::Api::GoSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/client.rb
Overview
Settings for Go client libraries.
Defined Under Namespace
Classes: RenamedServicesEntry
Instance Attribute Summary collapse
-
#common ⇒ ::Google::Api::CommonLanguageSettings
Some settings.
-
#renamed_services ⇒ ::Google::Protobuf::Map{::String => ::String}
Map of service names to renamed services.
Instance Attribute Details
#common ⇒ ::Google::Api::CommonLanguageSettings
Returns Some settings.
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'proto_docs/google/api/client.rb', line 344 class GoSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class RenamedServicesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#renamed_services ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.
Example:
publishing:
go_settings:
renamed_services:
Publisher: TopicAdmin.
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'proto_docs/google/api/client.rb', line 344 class GoSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class RenamedServicesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |